SequentialGroupQuota
===========================================

.. currentmodule:: alfred3_interact.quota

.. autoclass:: SequentialGroupQuota
   :show-inheritance:




   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
      :toctree:




      ~SequentialGroupQuota.count


      ~SequentialGroupQuota.next







   .. rubric:: Attributes

   .. autosummary::
      :template: autosummary/attribute.rst
      :toctree:


         ~SequentialGroupQuota.DATA_TYPE
         ~SequentialGroupQuota.allfinished
         ~SequentialGroupQuota.full
         ~SequentialGroupQuota.group_type
         ~SequentialGroupQuota.nfinished
         ~SequentialGroupQuota.nopen
         ~SequentialGroupQuota.npending
